import matplotlib.pyplot as plt
import pandas

# Lecture des donnees
entreprises = pandas.read_csv('entreprises.csv', sep = ',', encoding = 'latin-1')
geographie = pandas.read_csv('geographie.csv', sep = ',', encoding = 'latin-1')
salaires = pandas.read_csv('salaires.csv', sep = ',', encoding = 'latin-1')

# Preparation des donnees
entreprises = entreprises[entreprises['CODGEO'].apply(lambda x: str(x).isdigit())]
entreprises['CODGEO'] = entreprises['CODGEO'].astype(int)
entreprises['Micro'] = entreprises['E14TS1'] + entreprises['E14TS6']
entreprises['Petite'] = entreprises['E14TS10'] + entreprises['E14TS20']
entreprises['Medium'] = entreprises['E14TS50'] + entreprises['E14TS100']
entreprises['Grande'] = entreprises['E14TS200'] + entreprises['E14TS500']
entreprises['Somme'] = entreprises['E14TS1'] + entreprises['E14TS6'] + entreprises['E14TS10'] + entreprises['E14TS20'] + entreprises['E14TS50'] + entreprises['E14TS100'] + entreprises['E14TS200'] + entreprises['E14TS500']
entreprises['Micro%'] = entreprises['Micro'] * 100 / entreprises['Somme']
entreprises['Petite%'] = entreprises['Petite'] * 100 / entreprises['Somme']
entreprises['Medium%'] = entreprises['Medium'] * 100 / entreprises['Somme']
entreprises['Grande%'] = entreprises['Grande'] * 100 / entreprises['Somme']
selection_colonnes = ['CODGEO', 'LIBGEO', 'REG', 'DEP', 'Somme', 'Micro', 'Petite', 'Medium', 'Grande', 'Micro%', 'Petite%', 'Medium%', 'Grande%']
entreprises = entreprises[selection_colonnes]

geographie.drop(['EU_circo', 'code_region', 'eloignement', 'numero_departement', 'nom_departement', 'prefecture', 'numero_circonscription', 'codes_postaux'], axis=1, inplace=True)
geographie['longitude'] = geographie['longitude'].apply(lambda x: str(x).replace(',','.'))
supprimer = geographie['longitude'] == '-'
geographie.drop(geographie[supprimer].index, inplace=True)
geographie.dropna(subset = ['longitude', 'latitude'], inplace=True)
geographie['longitude'] = geographie['longitude'].astype(float)
geographie.drop_duplicates(subset=["code_insee"], keep="first", inplace=True)

salaires = salaires[salaires['CODGEO'].apply(lambda x: str(x).isdigit())]
salaires["CODGEO"] = salaires["CODGEO"].astype(int)

#Fusion des donnees entreprises et geographie
data = entreprises.merge(geographie, how='left', left_on = 'CODGEO', right_on='code_insee')

#Carte dynamique des 1000 communes les plus porteuses d'emploi
data.dropna(subset = ['longitude', 'latitude', 'Somme'], inplace=True)
import folium
lat_moy = data['latitude'].mean()
long_moy = data['longitude'].mean()
carte = folium.Map(location = [lat_moy, long_moy], zoom_start = 6, tiles = 'Stamen Terrain')
top1000 = data.sort_values(by = 'Somme').tail(1000)

from math import sqrt, pi
for k in top1000.index.values :
    latitude = top1000.loc[k, 'latitude']
    longitude = top1000.loc[k, 'longitude']
    rayon = sqrt(top1000.loc[k, 'Somme']/(100*pi))
    folium.CircleMarker([latitude, longitude], radius = rayon).add_to(carte)

carte.save('C:/Users/dutar/Desktop/carte.html')

#Répartition des emplois par regions
regions = data[['nom_region', 'Somme']].groupby('nom_region').sum().sort_values('Somme', ascending = False)
regions.plot.bar()

#Etude des salaires
salaires['diff_moyen'] = salaires['SNHMH14'] - salaires['SNHMF14']
salaires['diff_cadres_sup'] = salaires['SNHMHC14'] - salaires['SNHMFC14']
salaires['diff_profs_inter'] = salaires['SNHMHP14'] - salaires['SNHMFP14']
salaires['diff_employes'] = salaires['SNHMHE14'] - salaires['SNHMFE14']
salaires['diff_ouvriers'] = salaires['SNHMHO14'] - salaires['SNHMFO14']
tri1 = salaires.sort_values(by = 'diff_moyen', ascending = False)
tri2 = salaires.sort_values(by = 'diff_cadres_sup', ascending = False)
tri3 = salaires.sort_values(by = 'diff_profs_inter', ascending = False)
tri4 = salaires.sort_values(by = 'diff_employes', ascending = False)
tri5 = salaires.sort_values(by = 'diff_ouvriers', ascending = False)
salaires['diff_moyen%'] = salaires['diff_moyen'] * 100 / salaires['SNHM14']
salaires['diff_cadres_sup%'] = salaires['diff_cadres_sup'] * 100 / salaires['SNHMC14']
salaires['diff_profs_inter%'] = salaires['diff_profs_inter'] * 100 / salaires['SNHMP14']
salaires['diff_employes%'] = salaires['diff_employes'] * 100 / salaires['SNHME14']
salaires['diff_ouvriers%'] = salaires['diff_ouvriers'] * 100 / salaires['SNHMO14']
salaires_Paris = salaires[salaires.LIBGEO == 'Paris']